==> scribes_0.3.2.9.orig.tar.gz: scribes-0.3.2.9/plugins/Preferences/i18n.py <==
# -*- coding: utf-8 -*-
# Copyright © 2006 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

from gettext import gettext
_ = gettext
msg0001 = _("<b>Font</b>")
msg0002 = _("Editor _font: ")
msg0003 = _("<b>Tab Stops</b>")
msg0004 = _("_Tab width: ")
msg0005 = _("<b>Text Wrapping</b>")
msg0006 = _("<b>Right Margin</b>")
msg0007 = _("_Right margin position: ")
msg0008 = _("<b>Spell Checking</b>")
msg0009 = _("Change editor settings")
msg0010 = _("Preferences")
msg0011 = _("Changed font to \"%s\"")
msg0012 = _("Changed tab width to %d")
msg0013 = _("_Use spaces instead of tabs")
msg0014 = _("Use tabs for indentation")
msg0015 = _("Use spaces for indentation")
msg0016 = _("Enable text _wrapping")
msg0017 = _("Enabled text wrapping")
msg0018 = _("Disabled text wrapping")
msg0019 = _("Display right _margin")
msg0020 = _("Show right margin")
msg0021 = _("Hide right margin")
msg0022 = _("_Enable spell checking")
msg0023 = _("Enabled spellchecking")
msg0024 = _("Disabled spellchecking")
msg0025 = _("Positioned margin line at column %d")

==> scribes_0.3.3.3.orig.tar.gz: scribes-0.3.3.3/plugins/Preferences/i18n.py <==
# -*- coding: utf-8 -*-
# Copyright © 2006 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

from gettext import gettext as _
msg0001 = _("<b>Font</b>")
msg0002 = _("Editor _font: ")
msg0003 = _("<b>Tab Stops</b>")
msg0004 = _("_Tab width: ")
msg0005 = _("<b>Text Wrapping</b>")
msg0006 = _("<b>Right Margin</b>")
msg0007 = _("_Right margin position: ")
msg0008 = _("<b>Spell Checking</b>")
msg0009 = _("Change editor settings")
msg0010 = _("Preferences")
msg0011 = _("Changed font to \"%s\"")
msg0012 = _("Changed tab width to %d")
msg0013 = _("_Use spaces instead of tabs")
msg0014 = _("Use tabs for indentation")
msg0015 = _("Use spaces for indentation")
msg0016 = _("Enable text _wrapping")
msg0017 = _("Enabled text wrapping")
msg0018 = _("Disabled text wrapping")
msg0019 = _("Display right _margin")
msg0020 = _("Show right margin")
msg0021 = _("Hide right margin")
msg0022 = _("_Enable spell checking")
msg0023 = _("Enabled spellchecking")
msg0024 = _("Disabled spellchecking")
msg0025 = _("Positioned margin line at column %d")
